@@ -13,7 +13,7 @@ setMethod("rpf.info", signature(m="rpf.1dim.graded", param="numeric", theta="num
 
 setMethod("rpf.rparam", signature(m="rpf.1dim.graded"),
           function(m) {
-              a <- rlnorm(1, meanlog=0, sdlog=m@a.prior.sdlog)
+              a <- rlnorm(1, meanlog=0, sdlog=.5)
               b <- sort(rnorm(m@numOutcomes-1))
               c(a=a,b=b)
           })
@@ -22,7 +22,7 @@ setMethod("rpf.rparam", signature(m="rpf.1dim.graded"),
 
 setMethod("rpf.rparam", signature(m="rpf.mdim.graded"),
           function(m) {
-              a <- rlnorm(m@dimensions, meanlog=0, sdlog=m@a.prior.sdlog)
+              a <- rlnorm(m@dimensions, meanlog=0, sdlog=.5)
               b <- sort(rnorm(m@numOutcomes-1))
               c(a=a,b=b)
           })
